# `recon.stats`

The stats module implements utility functions for getting statistics for an NER dataset.
It's useful for getting a quick overview of your data and checking that you have enough examples for each label (including examples with **NO ENTITIES**)

---
## API

### ner_stats

::: recon.stats.ner_stats
    :docstring:
